# -*- coding: utf-8 -*-
"""
Created on Fri Dec 24 01:38:05 2021

@author: 
Розыев Ата
Мамаджанов Азиз
Джаводов Санджар
Гордеева Евгения
"""

from setuptools import setup, find_packages
long_description= '''Library for the 3 semester'''
setup(name='Zadacha',
      version='1.6',
      url='https://github.com/Rozyyev23/Library_AR',
      license='MIT',
      author='Rozyyev23',
      author_email='atarozyev2307@gmail.com',
      description='Add static script_dir() method to Path',
      zip_safe=False)
